@@ -1,12 +1,11 @@
 edeci <-
 function(x,y,index,k=5)
-  { #Value and Chebyshev confidence interval (mean-k*s,mean+k*s) for EDE as defined in papers:
+  { #Value and Chebyshev confidence interval (mean-k*s,mean+k*s) for EDE as defined in paper:
+    #    
+    # Demetris T. Christopoulos, On the efficient identification of an inflection point,
+    # International Journal of Mathematics and Scientific Computing,(ISSN: 2231-5330), vol. 6(1),
+    # https://www.researchgate.net/publication/304557351 , 2016
     #
-    #Demetris T. Christopoulos, 'On the efficient identification of an inflection point',
-    #International Journal of Mathematics and Scientific Computing,(ISSN: 2231-5330), VOL. 6, NO. 1, 2016
-    #
-    #Demetris T. Christopoulos, 'Developing methods for identifying the inflection point
-    #of a convex/ concave curve'. arXiv:1206.5478v2 [math.NA], 2012
     #Contact Emails: dchristop@econ.uoa.gr or dem.christop@gmail.com
     #
     tede=ede(x,y,index);m=tede[3];
